======
pfrock
======

A plugin-based tool for running fake HTTP and socket services using Python.

.. pfrock: https://pypi.python.org/pypi/pfrock

for more details, see github: https://github.com/knightliao/pfrock